@@ -68,16 +68,14 @@ SEXP R_H5Tclose(SEXP R_type_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Tcommit2(hid_t loc_id, const char *name, hid_t type_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id); */
-SEXP R_H5Tcommit2(SEXP R_loc_id, SEXP R_name, SEXP R_type_id, SEXP R_lcpl_id, SEXP R_tcpl_id, SEXP R_tapl_id){
+/* H5_DLL herr_t H5Tcommit_anon(hid_t loc_id, hid_t type_id, hid_t tcpl_id, hid_t tapl_id); */
+SEXP R_H5Tcommit_anon(SEXP R_loc_id, SEXP R_type_id, SEXP R_tcpl_id, SEXP R_tapl_id){
   int vars_protected=0;
   hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
-  const char* name = CHAR(STRING_ELT(R_name, 0));
   hid_t type_id = SEXP_to_longlong(R_type_id, 0);
-  hid_t lcpl_id = SEXP_to_longlong(R_lcpl_id, 0);
   hid_t tcpl_id = SEXP_to_longlong(R_tcpl_id, 0);
   hid_t tapl_id = SEXP_to_longlong(R_tapl_id, 0);
-  herr_t return_val = H5Tcommit2(loc_id, name, type_id, lcpl_id, tcpl_id, tapl_id);
+  herr_t return_val = H5Tcommit_anon(loc_id, type_id, tcpl_id, tapl_id);
   SEXP R_return_val= R_NilValue;
   R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
   vars_protected++;
@@ -93,14 +91,16 @@ SEXP R_H5Tcommit2(SEXP R_loc_id, SEXP R_name, SEXP R_type_id, SEXP R_lcpl_id, SE
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Tcommit_anon(hid_t loc_id, hid_t type_id, hid_t tcpl_id, hid_t tapl_id); */
-SEXP R_H5Tcommit_anon(SEXP R_loc_id, SEXP R_type_id, SEXP R_tcpl_id, SEXP R_tapl_id){
+/* H5_DLL herr_t H5Tcommit2(hid_t loc_id, const char *name, hid_t type_id, hid_t lcpl_id, hid_t tcpl_id, hid_t tapl_id); */
+SEXP R_H5Tcommit2(SEXP R_loc_id, SEXP R_name, SEXP R_type_id, SEXP R_lcpl_id, SEXP R_tcpl_id, SEXP R_tapl_id){
   int vars_protected=0;
   hid_t loc_id = SEXP_to_longlong(R_loc_id, 0);
+  const char* name = CHAR(STRING_ELT(R_name, 0));
   hid_t type_id = SEXP_to_longlong(R_type_id, 0);
+  hid_t lcpl_id = SEXP_to_longlong(R_lcpl_id, 0);
   hid_t tcpl_id = SEXP_to_longlong(R_tcpl_id, 0);
   hid_t tapl_id = SEXP_to_longlong(R_tapl_id, 0);
-  herr_t return_val = H5Tcommit_anon(loc_id, type_id, tcpl_id, tapl_id);
+  herr_t return_val = H5Tcommit2(loc_id, name, type_id, lcpl_id, tcpl_id, tapl_id);
   SEXP R_return_val= R_NilValue;
   R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
   vars_protected++;
@@ -496,26 +496,6 @@ SEXP R_H5Tequal(SEXP R_type1_id, SEXP R_type2_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Tflush(hid_t type_id); */
-SEXP R_H5Tflush(SEXP R_type_id){
-  int vars_protected=0;
-  hid_t type_id = SEXP_to_longlong(R_type_id, 0);
-  herr_t return_val = H5Tflush(type_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL int H5Tget_array_dims2(hid_t type_id, hsize_t dims[]); */
 SEXP R_H5Tget_array_dims2(SEXP R_type_id, SEXP R_dims){
   hsize_t size_helper;
@@ -841,7 +821,7 @@ SEXP R_H5Tget_member_name(SEXP R_type_id, SEXP R_membno){
   SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
   SET_NAMES(__ret_list, __ret_list_names);
   vars_protected += 2;
-  H5free_memory(return_val);
+  free(return_val);
   UNPROTECT(vars_protected);
   return(__ret_list);
 }
@@ -1199,7 +1179,7 @@ SEXP R_H5Tget_tag(SEXP R_type){
   SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
   SET_NAMES(__ret_list, __ret_list_names);
   vars_protected += 2;
-  H5free_memory(return_val);
+  free(return_val);
   UNPROTECT(vars_protected);
   return(__ret_list);
 }
@@ -1309,26 +1289,6 @@ SEXP R_H5Tpack(SEXP R_type_id){
   return(__ret_list);
 }
 
-/* H5_DLL herr_t H5Trefresh(hid_t type_id); */
-SEXP R_H5Trefresh(SEXP R_type_id){
-  int vars_protected=0;
-  hid_t type_id = SEXP_to_longlong(R_type_id, 0);
-  herr_t return_val = H5Trefresh(type_id);
-  SEXP R_return_val= R_NilValue;
-  R_return_val = PROTECT(ScalarInteger64_or_int(return_val));
-  vars_protected++;
-  SEXP __ret_list;
-  PROTECT(__ret_list = allocVector(VECSXP, 1));
-  SET_VECTOR_ELT(__ret_list, 0, R_return_val);
-  SEXP __ret_list_names;
-  PROTECT(__ret_list_names = allocVector(STRSXP, 1));
-  SET_STRING_ELT(__ret_list_names, 0, mkChar("return_val"));
-  SET_NAMES(__ret_list, __ret_list_names);
-  vars_protected += 2;
-  UNPROTECT(vars_protected);
-  return(__ret_list);
-}
-
 /* H5_DLL herr_t H5Tset_cset(hid_t type_id, H5T_cset_t cset); */
 SEXP R_H5Tset_cset(SEXP R_type_id, SEXP R_cset){
   int vars_protected=0;
